#!/usr/bin/env bash
export FLIT_PASSWORD="pypi-AgEIcHlwaS5vcmcCJGNmYmM0ZDY3LTUyYjYtNDk0Yi1iNTQwLTlhZWNlNGZmNGYzYgACJXsicGVybWlzc2lvbnMiOiAidXNlciIsICJ2ZXJzaW9uIjogMX0AAAYgST8aTOCfPNU6Rdsc3tZPmI8X0SS1d6-dN06I2Oa-PwA"
export FLIT_INDEX_URL="https://upload.pypi.org/legacy/"
flit publish
