#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['blue_chip', 'blue_chip.config', 'blue_chip.tasks']

package_data = \
{'': ['*'], 'blue_chip': ['lintrc/*']}

install_requires = \
['black', 'invoke', 'prospector[with_pyroma]']

entry_points = \
{'console_scripts': ['bc = blue_chip.__main__:program.run',
                     'bcp = blue_chip.__main__:program.run']}

setup(name='blue-chip',
      version='0.0.4',
      description='blue_chip',
      author='Gabriel Gore',
      author_email='gabriel59kg@gmail.com',
      url='https://github.com/Kilo59/blue-chip',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      entry_points=entry_points,
      python_requires='>=3.6',
     )
